==> kirigami-addons-1.7.0.tgz: include/KirigamiAddonsStatefulApp/kirigamiaddonsstatefulapp_export.h <==

#ifndef KIRIGAMIADDONSSTATEFULAPP_EXPORT_H
#define KIRIGAMIADDONSSTATEFULAPP_EXPORT_H

#ifdef KIRIGAMIADDONSSTATEFULAPP_STATIC_DEFINE
#  define KIRIGAMIADDONSSTATEFULAPP_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT
#else
#  ifndef KIRIGAMIADDONSSTATEFULAPP_EXPORT
#    ifdef KirigamiAddonsStatefulApp_EXPORTS
        /* We are building this library */
#      define KIRIGAMIADDONSSTATEFULAPP_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIRIGAMIADDONSSTATEFULAPP_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT
#    define KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_EXPORT KIRIGAMIADDONSSTATEFULAPP_EXPORT KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED
#endif

#ifndef KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_NO_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_NO_EXPORT KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED
#    define KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED
#  endif
#endif

#define KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED)
#  undef KIRIGAMIADDONSSTATEFULAPP_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_EXPORT KIRIGAMIADDONSSTATEFULAPP_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_NO_EXPORT KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT
#elif defined(KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED_WARNINGS)
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_EXPORT KIRIGAMIADDONSSTATEFULAPP_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_NO_EXPORT KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT
#else
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_EXPORT KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_NO_EXPORT KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KIRIGAMIADDONSSTATEFULAPP_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KIRIGAMIADDONSSTATEFULAPP_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT 0x10700
#endif
#ifdef KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED_WARNINGS
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_WARNINGS_SINCE
#  ifdef KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_WARNINGS_SINCE KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_WARNINGS_SINCE 0x10700
#  endif
#endif

#ifndef KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT 0x10000
#endif

#ifdef KIRIGAMIADDONSSTATEFULAPP_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KIRIGAMIADDONSSTATEFULAPP_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KIRIGAMIADDONSSTATEFULAPP_EXPORT_H */

==> kirigami-addons-1.11.0.tgz: include/KirigamiAddonsStatefulApp/kirigamiaddonsstatefulapp_export.h <==

#ifndef KIRIGAMIADDONSSTATEFULAPP_EXPORT_H
#define KIRIGAMIADDONSSTATEFULAPP_EXPORT_H

#ifdef KIRIGAMIADDONSSTATEFULAPP_STATIC_DEFINE
#  define KIRIGAMIADDONSSTATEFULAPP_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT
#else
#  ifndef KIRIGAMIADDONSSTATEFULAPP_EXPORT
#    ifdef KirigamiAddonsStatefulApp_EXPORTS
        /* We are building this library */
#      define KIRIGAMIADDONSSTATEFULAPP_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIRIGAMIADDONSSTATEFULAPP_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT
#    define KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_EXPORT KIRIGAMIADDONSSTATEFULAPP_EXPORT KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED
#endif

#ifndef KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_NO_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_NO_EXPORT KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED
#    define KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED
#  endif
#endif

#define KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED)
#  undef KIRIGAMIADDONSSTATEFULAPP_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_EXPORT KIRIGAMIADDONSSTATEFULAPP_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_NO_EXPORT KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT
#elif defined(KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED_WARNINGS)
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_EXPORT KIRIGAMIADDONSSTATEFULAPP_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_NO_EXPORT KIRIGAMIADDONSSTATEFULAPP_NO_EXPORT
#else
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_EXPORT KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_NO_EXPORT KIRIGAMIADDONSSTATEFULAPP_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KIRIGAMIADDONSSTATEFULAPP_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KIRIGAMIADDONSSTATEFULAPP_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT 0x10b00
#endif
#ifdef KIRIGAMIADDONSSTATEFULAPP_NO_DEPRECATED_WARNINGS
#  define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_WARNINGS_SINCE
#  ifdef KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_WARNINGS_SINCE KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KIRIGAMIADDONSSTATEFULAPP_DEPRECATED_WARNINGS_SINCE 0x10b00
#  endif
#endif

#ifndef KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT 0x10000
#endif

#ifdef KIRIGAMIADDONSSTATEFULAPP_DEPRECATED
#  define KIRIGAMIADDONSSTATEFULAPP_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KIRIGAMIADDONSSTATEFULAPP_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KIRIGAMIADDONSSTATEFULAPP_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KIRIGAMIADDONSSTATEFULAPP_EXPORT_H */
